pyLBM.elements.Sphere
=====================

.. currentmodule:: pyLBM.elements

.. autoclass:: Sphere

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Sphere.distance
         Sphere.get_bounds
         Sphere.point_inside
         Sphere.test_label



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Sphere.number_of_bounds

